AntiImportError


Avoiding getting "ImportError: attempted relative import with no known parent package" by simply adding parent folder directory to system path. 

Source code:
https://github.com/eonianmonk/AntiImportError

To import function use:
from upper_folder_getter import get_upper_folder 
